// 60 sec
const DEFAULT_INTERVAL_MS = 60000;

let lastResId = 0;

// 既に初期化済みかどうか
// （初回だけ"通知なし"で最新res_idを取得する）
let initialized = false;

(async function init() {
  // chrome.storageから前回情報を読み込み
  const data = await chrome.storage.local.get(["lastResId", "initialized"]);
  if (data.lastResId) {
    lastResId = data.lastResId;
  }
  if (data.initialized) {
    initialized = data.initialized;
  }

  // 初回起動でまだinitialized=falseの場合→
  // 一度だけAPIをfetchして最新のres_idだけ取得して保存、通知は出さない
  if (!initialized) {
    const newestId = await fetchLatestResId();
    if (newestId) {
      lastResId = newestId;
      await chrome.storage.local.set({
        lastResId,
        initialized: true
      });
    }
    // initializedをtrueにして以後のループで通知する
    initialized = true;
  }

  // 以後、30秒ごとにチェック
  setInterval(() => {
    checkMainListApi();
  }, DEFAULT_INTERVAL_MS);
})();

/**
 * 一度だけ実行して、最新のres配列の先頭を取得 → そのres_idを返す
 * 通知は行わない
 */
async function fetchLatestResId() {
  try {
    const url = "https://tw8.t-walker.jp/api/main_list?n=0";
    const resp = await fetch(url);
    if (!resp.ok) {
      console.warn("Initial fetch failed:", resp.status);
      return null;
    }
    const json = await resp.json();
    if (!json.res || json.res.length === 0) return null;

    // 新しい順に並んでいるので、先頭の res[0].res_id が最新
    const newestId = json.res[0].res_id;
    return newestId;
  } catch (e) {
    console.error("fetchLatestResId error:", e);
    return null;
  }
}

/**
 * 定期確認
 */
async function checkMainListApi() {
  try {
    const url = "https://tw8.t-walker.jp/api/main_list?n=0";
    const resp = await fetch(url);
    if (!resp.ok) {
      console.warn("API fetch failed:", resp.status);
      return;
    }
    const json = await resp.json();
    if (!json.res || json.res.length === 0) return;

    // (2) 前回の lastResId を見つけるまでリストを走査
    // resは新しい順に並んでいる想定
    const newPosts = [];
    for (let i = 0; i < json.res.length; i++) {
      const item = json.res[i];
      if (item.res_id > lastResId) {
        newPosts.push(item);
      } else {
        break;
      }
    }

    // 新着があれば通知（＝ background.js へ sendMessage）
    if (newPosts.length > 0) {
      // newPostsは "新しい順" になっているので逆順にすると古い→新しい順で通知するなど可能
      // ここではそのまま送る
      chrome.runtime.sendMessage({
        type: "newRes",
        items: newPosts
      });

      // newPosts の中の最大res_id を更新する
      // 一番最初が最新のはずなので、それを使えばOK
      const maxResId = newPosts[0].res_id;
      lastResId = maxResId;

      // chrome.storageに書き戻す
      await chrome.storage.local.set({ lastResId });
    }

  } catch (err) {
    console.error("checkMainListApi error:", err);
  }
}
